pub fn decode(data: &[u8], provider: &dyn DeclProvider) -> Option<Value>Expand description
decode a given binary data into a Value.
the data must start with a header specifing the path to the declaration file and the root value typeid.
if the decl_path field is an empty string, the type is any implicitly.
it returns None if the data is invalid, or if there is unused space at the end of the input.