Key

Enum Key 

pub enum Key {
    Bool(bool),
    Int(i64),
    Uint(u64),
    BigInt(BigInt),
    Str(String),
    Inst(DateTime<Utc>),
    Dur(TimeDelta),
    UUID([u8; 16]),
}
a type used as Value::Map key.

Key is a subset of Value for types that can be used a keys for Value::Map.

it supports all the api supported by its underlaying variants, and can be converted from and into Value.

example

let map = Value::Map(HashMap::new())
	.insert(Key::from("some_key"), Value::Uint(1)); // => {"some_key": 1}

Variants



Bool(bool)

boolean value, types: bool.



Int(i64)

signed integer value, types: i8, i16, i32, i64 vint.



Uint(u64)

unsigned integer value, types: u8, u16, u32, u64 vuint.



BigInt(BigInt)

big integer value, types: bint.



Str(String)

string value, types: str.



Inst(DateTime<Utc>)

instance value, types: inst, instN.



Dur(TimeDelta)

duration value, types: dur.



UUID([u8; 16])

uuid value, types: uuid.

Implementations

Source

impl Key

pub fn enum_variant_key() -> &'static Key

the enum variant key in an enum map

pub fn has_meta_key() -> &'static Key

the has metadata key in a metadata wrapped type

pub fn inner_key() -> &'static Key

the inner value key of a metadata wrapped type

Source

impl Key

is_T() -> bool: whether the inner value is of type T.

pub fn is_bool(&self) -> bool

pub fn is_uint(&self) -> bool

pub fn is_int(&self) -> bool

pub fn is_str(&self) -> bool

pub fn is_bigint(&self) -> bool

pub fn is_inst(&self) -> bool

pub fn is_dur(&self) -> bool

pub fn is_uuid(&self) -> bool

Source

impl Key

pub fn cast<T>(self) -> Option<T>
where Key: TryInto<T>,

cast key into T

Source

impl Key

as_T() -> Option<T>: get copy / reference of the inner value if it is of type T, else None.

pub fn as_bool(&self) -> Option<bool>

pub fn as_int(&self) -> Option<i64>

pub fn as_uuid(&self) -> Option<[u8; 16]>

pub fn as_dur(&self) -> Option<TimeDelta>

pub fn as_inst(&self) -> Option<DateTime<Utc>>

pub fn as_uint(&self) -> Option<u64>

pub fn as_str(&self) -> Option<&str>

pub fn as_bigint(&self) -> Option<&BigInt>