functions and types related to encoding and decoding.
in addition to the visible items, this module exports undocumented helper functions used by the generated serialization code that are not intended to be used directly.
Traits
- Serialized
- trait for types that can be serialized and deserialized.